==> haskell-hslua-packaging-2.3.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-packaging.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-packaging
version:              2.3.1
visibility:           public
id:                   hslua-packaging-2.3.1-CWRoaUxzdqII2MImvJ2wj2
key:                  hslua-packaging-2.3.1-CWRoaUxzdqII2MImvJ2wj2
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Utilities to build Lua modules.
description:
    Utilities to package up Haskell functions and
    values into a Lua module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  32562608e2fc51dfd8ee8cddeced5f31
exposed:              True
exposed-modules:
    HsLua.Packaging HsLua.Packaging.Convenience
    HsLua.Packaging.Documentation HsLua.Packaging.Function
    HsLua.Packaging.Module HsLua.Packaging.Rendering
    HsLua.Packaging.Types HsLua.Packaging.UDType

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-packaging-2.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-packaging-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-packaging
hs-libraries:         HShslua-packaging-2.3.1-CWRoaUxzdqII2MImvJ2wj2
depends:
    base-4.16.4.0 containers-0.6.5.1
    hslua-core-2.3.1-1bLwXxpG3y4x6P7QmoCw1
    hslua-marshalling-2.3.1-EugHDCOqHZqHeFQAh5G7I4
    hslua-objectorientation-2.3.0-IfCEDq5MCjUCjseCRCtY07
    hslua-typing-0.1.1-K9ACm0NXSfX1JkasUC8sV3 mtl-2.2.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-packaging/html/hslua-packaging.haddock

haddock-html:         /usr/share/doc/haskell-hslua-packaging/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-packaging-2.3.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-packaging.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-packaging
version:              2.3.1
visibility:           public
id:                   hslua-packaging-2.3.1-4vC7ipHnVGE4NsUFEnHrS4
key:                  hslua-packaging-2.3.1-4vC7ipHnVGE4NsUFEnHrS4
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Utilities to build Lua modules.
description:
    Utilities to package up Haskell functions and
    values into a Lua module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  91c2347c909af5f0607c3995b0e55fe5
exposed:              True
exposed-modules:
    HsLua.Packaging HsLua.Packaging.Convenience
    HsLua.Packaging.Documentation HsLua.Packaging.Function
    HsLua.Packaging.Module HsLua.Packaging.Rendering
    HsLua.Packaging.Types HsLua.Packaging.UDType

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-packaging-2.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-packaging-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-packaging
hs-libraries:         HShslua-packaging-2.3.1-4vC7ipHnVGE4NsUFEnHrS4
depends:
    base-4.16.4.0 containers-0.6.5.1
    hslua-core-2.3.1-IsFMBWu7Yi17Ek8T4ODXO0
    hslua-marshalling-2.3.1-9WmkKWBXpdbA1UVALVXwp
    hslua-objectorientation-2.3.0-IpMqzRfhuuCGFQmAc2wqR0
    hslua-typing-0.1.1-GOeqvb5pANKHrLOP8ccBwO mtl-2.2.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-packaging/html/hslua-packaging.haddock

haddock-html:         /usr/share/doc/haskell-hslua-packaging/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
